Future location of Python enabled Xyce.

In the meantime, check out Xyce-PyMi at:
https://github.com/xyce/xyce

with instruction details at:
https://cfwebprod.sandia.gov/cfdocs/CompResearch/docs/Xyce-PyMi-Guide.pdf



About Xyce:

Xyce (rhymes with "spice") is an open source, SPICE-compatible, high-performance analog circuit simulator, capable of solving extremely large circuit problems by supporting large-scale parallel computing platforms. It also supports serial execution on all common desktop platforms, and small-scale parallel runs on Unix-like systems. In addition to analog electronic simulation, Xyce has also been used to investigate more general network systems, such as neural networks and power grids. In providing an Open Source version of Xyce to the external community, Sandia hopes to contribute a robust and modern electronic simulator to users and researchers in the field.

While designed to be SPICE-compatible, Xyce is not a derivative of SPICE. Xyce was designed from scratch to be a parallel simulation code, written in C++ and using a message-passing implementation (MPI). Xyce also leverages Sandia's open-source solver library, Trilinos, which includes a number of circuit-specific solvers, such as the KLU direct solver. With its modular and flexible design, Xyce applies abstract interfaces to enable easy development of different analysis types, solvers and models.

Xyce is compatible with SPICE-based codes, in that it supports a canonical set of SPICE compact models and standard SPICE analysis methods, such as steady-state (.DC), transient (.TRAN), small-signal frequency domain (.AC), and noise (.NOISE). However, Xyce goes beyond most SPICE-based codes in a number of ways, including support for a large number of non-traditional models, such as neuron and reaction network models. Xyce also supports Harmonic Balance analysis (.HB), random sampling analysis, sensitivity calculations, and post processing of the simulation metrics (.FOUR and .MEASURE).

